@@ -17,7 +17,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 // Copyright Author Dany De Bontridder ddebontridder@yahoo.fr
-/* $Revision: 1.32 $ */
+/* $Revision: 1.33 $ */
 
 /* function RecordJrn
  * Purpose : Record an entry in the selected journal
@@ -849,7 +849,7 @@ function VerifData($p_cn,$p_array,$p_user)
       return BADDATE;
     }
     // userPref contient la periode par default
-    $userPref=GetUserPeriode($p_cn,$p_user);
+    $userPref=$p_user->GetPeriode();
     list ($l_date_start,$l_date_end)=GetPeriode($p_cn,$userPref);
 
     // Date dans la periode active
